@@ -77,6 +77,12 @@ impl Context {
             .into()
     }
 
+    /// Utility function to sleep tasks from other crates
+    #[doc(hidden)]
+    pub async fn sleep(&self, dur: Duration) {
+        tokio::time::sleep(dur).await;
+    }
+
     /// Create a new context without spawning a full worker
     pub async fn new_context<S: Into<Address>>(&self, addr: S) -> Result<Context> {
         let addr = addr.into();
@@ -277,6 +283,12 @@ impl Context {
         Ok(())
     }
 
+    /// Receive a message without a timeout
+    pub async fn receive_block<'ctx, M: Message>(&'ctx mut self) -> Result<Cancel<'ctx, M>> {
+        let (msg, data, addr) = self.next_from_mailbox().await?;
+        Ok(Cancel::new(msg, data, addr, self))
+    }
+
     /// Block the current worker to wait for a typed message
     ///
     /// This function may return a `Err(FailedLoadData)` if the
