@@ -26,6 +26,8 @@ pub enum Error {
     InternalIOFailure,
     /// Worker tried to send message from foreign address
     SenderAddressDoesntExist,
+    /// Operation timed out
+    Timeout,
 }
 
 impl Error {
@@ -58,3 +60,9 @@ impl<T: Debug> From<SendError<T>> for Error {
         Error::InternalIOFailure
     }
 }
+
+impl From<tokio::time::error::Elapsed> for Error {
+    fn from(_: tokio::time::error::Elapsed) -> Self {
+        Self::Timeout
+    }
+}
